@@ -5,9 +5,8 @@ import nbconvert  # type: ignore
 from fastapi import APIRouter, Depends
 from fastapi.responses import FileResponse
 from fps.hooks import register_router  # type: ignore
-
 from fps_auth.backends import current_user  # type: ignore
-from fps_auth.models import User  # type: ignore
+from fps_auth.models import UserRead  # type: ignore
 
 router = APIRouter()
 
@@ -15,9 +14,7 @@ router = APIRouter()
 @router.get("/api/nbconvert")
 async def get_nbconvert_formats():
     return {
-        name: {
-            "output_mimetype": nbconvert.exporters.get_exporter(name).output_mimetype
-        }
+        name: {"output_mimetype": nbconvert.exporters.get_exporter(name).output_mimetype}
         for name in nbconvert.exporters.get_export_names()
     }
 
@@ -27,7 +24,7 @@ async def get_nbconvert_document(
     format: str,
     path: str,
     download: bool,
-    user: User = Depends(current_user),
+    user: UserRead = Depends(current_user),
 ):
     exporter = nbconvert.exporters.get_exporter(format)
     if download:
